// Swig module description file for a C dynamic library source file
// Generate with: swig -c++ -python -o py_wrap.cpp pyniflib.i

/* Copyright (c) 2006, NIF File Format Library and Tools
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

   * Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.

   * Redistributions in binary form must reproduce the above
     copyright notice, this list of conditions and the following
     disclaimer in the documentation and/or other materials provided
     with the distribution.

   * Neither the name of the NIF File Format Library and Tools
     project nor the names of its contributors may be used to endorse
     or promote products derived from this software without specific
     prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
POSSIBILITY OF SUCH DAMAGE. */

%module niflib
%include "stl.i"
%include "std_map.i"
%include "exception.i"
%include "std_list.i"
%include "typemaps.i"

// enable string assignment in structure member functions
%typemap(in) std::string* ($*1_ltype tempstr) {
	char * temps; int templ;
 	if (PyString_AsStringAndSize($input, &temps, &templ)) return NULL;
 	tempstr = $*1_ltype(temps, templ);
 	$1 = &tempstr;
}
%typemap(out) std::string* "$result = PyString_FromStringAndSize($1->data(), $1->length());";

// we need a version of SWIG that has SWIG_CATCH_STDEXCEPT support
#if SWIG_VERSION >= 0x010322
%exception {
	try {
		$action
	}
	SWIG_CATCH_STDEXCEPT // catch std::exception
	catch (...) {
		SWIG_exception(SWIG_UnknownError, "Unknown exception");
	}
}
#endif

// we need to define this because the wrapper gets confused about NIFLIB_API'd functions otherwise
#define NIFLIB_API
#define NIFLIB_HIDDEN

//Ignore the const versions of these functions
%ignore DynamicCast( const NiObject * object );
%ignore StaticCast (const NiObject * object);

//Do not use smart pointer support as it doubles the size of the library
//and makes it take twice as long to be imported
%ignore Ref::operator->;
%ignore Ref::operator=;

// we need this to get all the defines in there
%include "gen/obj_defines.h"
%{
		#include "niflib.h"
		#include "Ref.h"
		#include "Type.h"
		#include "nif_math.h"
		#include "obj/NiObject.h"
		#include "obj/AKeyedData.h"
		#include "obj/AParticleModifier.h"
		#include "obj/bhkRefObject.h"
		#include "obj/bhkSerializable.h"
		#include "obj/AbhkConstraint.h"
		#include "obj/AbhkRagdollConstraint.h"
		#include "obj/bhkShape.h"
		#include "obj/AbhkShapeCollection.h"
		#include "obj/bhkSphereRepShape.h"
		#include "obj/bhkConvexShape.h"
		#include "obj/bhkWorldObject.h"
		#include "obj/bhkEntity.h"
		#include "obj/NiCollisionObject.h"
		#include "obj/NiExtraData.h"
		#include "obj/NiInterpolator.h"
		#include "obj/NiBlendInterpolator.h"
		#include "obj/NiBSplineInterpolator.h"
		#include "obj/NiObjectNET.h"
		#include "obj/NiAVObject.h"
		#include "obj/NiDynamicEffect.h"
		#include "obj/NiLight.h"
		#include "obj/NiProperty.h"
		#include "obj/NiPSysModifier.h"
		#include "obj/NiPSysEmitter.h"
		#include "obj/NiPSysVolumeEmitter.h"
		#include "obj/NiTimeController.h"
		#include "obj/ABoneLODController.h"
		#include "obj/NiSingleInterpolatorController.h"
		#include "obj/APSysCtlr.h"
		#include "obj/NiTriBasedGeom.h"
		#include "obj/NiTriBasedGeomData.h"
		#include "obj/APSysData.h"
		#include "obj/bhkBlendCollisionObject.h"
		#include "obj/bhkBlendController.h"
		#include "obj/bhkBoxShape.h"
		#include "obj/bhkCapsuleShape.h"
		#include "obj/bhkCollisionObject.h"
		#include "obj/bhkConvexVerticesShape.h"
		#include "obj/bhkHingeConstraint.h"
		#include "obj/bhkLimitedHingeConstraint.h"
		#include "obj/bhkListShape.h"
		#include "obj/bhkMalleableConstraint.h"
		#include "obj/bhkMoppBvTreeShape.h"
		#include "obj/bhkMultiSphereShape.h"
		#include "obj/bhkNiTriStripsShape.h"
		#include "obj/bhkPackedNiTriStripsShape.h"
		#include "obj/bhkPrismaticConstraint.h"
		#include "obj/bhkRagdollConstraint.h"
		#include "obj/bhkRigidBody.h"
		#include "obj/bhkRigidBodyT.h"
		#include "obj/bhkSimpleShapePhantom.h"
		#include "obj/bhkSPCollisionObject.h"
		#include "obj/bhkSphereShape.h"
		#include "obj/bhkStiffSpringConstraint.h"
		#include "obj/bhkTransformShape.h"
		#include "obj/bhkConvexTransformShape.h"
		#include "obj/BSBound.h"
		#include "obj/BSFurnitureMarker.h"
		#include "obj/BSParentVelocityModifier.h"
		#include "obj/BSPSysArrayEmitter.h"
		#include "obj/BSXFlags.h"
		#include "obj/hkPackedNiTriStripsData.h"
		#include "obj/NiAlphaController.h"
		#include "obj/NiAlphaProperty.h"
		#include "obj/NiAmbientLight.h"
		#include "obj/NiAutoNormalParticlesData.h"
		#include "obj/NiBinaryExtraData.h"
		#include "obj/NiBlendBoolInterpolator.h"
		#include "obj/NiBlendFloatInterpolator.h"
		#include "obj/NiBlendPoint3Interpolator.h"
		#include "obj/NiBlendTransformInterpolator.h"
		#include "obj/NiBoneLODController.h"
		#include "obj/NiBoolData.h"
		#include "obj/NiBooleanExtraData.h"
		#include "obj/NiBoolInterpolator.h"
		#include "obj/NiBoolTimelineInterpolator.h"
		#include "obj/NiBSBoneLODController.h"
		#include "obj/NiBSplineBasisData.h"
		#include "obj/NiBSplineCompFloatInterpolator.h"
		#include "obj/NiBSplineCompPoint3Interpolator.h"
		#include "obj/NiBSplineCompTransformInterpolator.h"
		#include "obj/NiBSplineData.h"
		#include "obj/NiCamera.h"
		#include "obj/NiCollisionData.h"
		#include "obj/NiColorData.h"
		#include "obj/NiColorExtraData.h"
		#include "obj/NiControllerManager.h"
		#include "obj/NiControllerSequence.h"
		#include "obj/NiDefaultAVObjectPalette.h"
		#include "obj/NiDirectionalLight.h"
		#include "obj/NiDitherProperty.h"
		#include "obj/NiFlipController.h"
		#include "obj/NiFloatData.h"
		#include "obj/NiFloatExtraData.h"
		#include "obj/NiFloatExtraDataController.h"
		#include "obj/NiFloatInterpolator.h"
		#include "obj/NiFloatsExtraData.h"
		#include "obj/NiFogProperty.h"
		#include "obj/NiGeomMorpherController.h"
		#include "obj/NiGravity.h"
		#include "obj/NiIntegerExtraData.h"
		#include "obj/NiIntegersExtraData.h"
		#include "obj/NiKeyframeController.h"
		#include "obj/BSKeyframeController.h"
		#include "obj/NiKeyframeData.h"
		#include "obj/NiLightColorController.h"
		#include "obj/NiLightDimmerController.h"
		#include "obj/NiLookAtController.h"
		#include "obj/NiLookAtInterpolator.h"
		#include "obj/NiMaterialColorController.h"
		#include "obj/NiMaterialProperty.h"
		#include "obj/NiMeshPSysData.h"
		#include "obj/NiMorphData.h"
		#include "obj/NiMultiTargetTransformController.h"
		#include "obj/NiNode.h"
		#include "obj/AvoidNode.h"
		#include "obj/FxWidget.h"
		#include "obj/FxButton.h"
		#include "obj/FxRadioButton.h"
		#include "obj/NiBillboardNode.h"
		#include "obj/NiBSAnimationNode.h"
		#include "obj/NiBSParticleNode.h"
		#include "obj/NiLODNode.h"
		#include "obj/NiPalette.h"
		#include "obj/NiParticleBomb.h"
		#include "obj/NiParticleColorModifier.h"
		#include "obj/NiParticleGrowFade.h"
		#include "obj/NiParticleMeshModifier.h"
		#include "obj/NiParticleRotation.h"
		#include "obj/NiParticles.h"
		#include "obj/NiAutoNormalParticles.h"
		#include "obj/NiParticleMeshes.h"
		#include "obj/NiParticlesData.h"
		#include "obj/NiParticleMeshesData.h"
		#include "obj/NiParticleSystem.h"
		#include "obj/NiMeshParticleSystem.h"
		#include "obj/NiParticleSystemController.h"
		#include "obj/NiBSPArrayController.h"
		#include "obj/NiPathController.h"
		#include "obj/NiPathInterpolator.h"
		#include "obj/NiPixelData.h"
		#include "obj/NiPlanarCollider.h"
		#include "obj/NiPoint3Interpolator.h"
		#include "obj/NiPointLight.h"
		#include "obj/NiPosData.h"
		#include "obj/NiPSysAgeDeathModifier.h"
		#include "obj/NiPSysBombModifier.h"
		#include "obj/NiPSysBoundUpdateModifier.h"
		#include "obj/NiPSysBoxEmitter.h"
		#include "obj/NiPSysColliderManager.h"
		#include "obj/NiPSysColorModifier.h"
		#include "obj/NiPSysCylinderEmitter.h"
		#include "obj/NiPSysData.h"
		#include "obj/NiPSysDragModifier.h"
		#include "obj/NiPSysEmitterCtlr.h"
		#include "obj/NiPSysEmitterCtlrData.h"
		#include "obj/NiPSysEmitterDeclinationCtlr.h"
		#include "obj/NiPSysEmitterDeclinationVarCtlr.h"
		#include "obj/NiPSysEmitterInitialRadiusCtlr.h"
		#include "obj/NiPSysEmitterLifeSpanCtlr.h"
		#include "obj/NiPSysEmitterSpeedCtlr.h"
		#include "obj/NiPSysGravityModifier.h"
		#include "obj/NiPSysGravityStrengthCtlr.h"
		#include "obj/NiPSysGrowFadeModifier.h"
		#include "obj/NiPSysMeshEmitter.h"
		#include "obj/NiPSysMeshUpdateModifier.h"
		#include "obj/NiPSysModifierActiveCtlr.h"
		#include "obj/NiPSysPlanarCollider.h"
		#include "obj/NiPSysPositionModifier.h"
		#include "obj/NiPSysResetOnLoopCtlr.h"
		#include "obj/NiPSysRotationModifier.h"
		#include "obj/NiPSysSpawnModifier.h"
		#include "obj/NiPSysSphereEmitter.h"
		#include "obj/NiPSysUpdateCtlr.h"
		#include "obj/NiRangeLODData.h"
		#include "obj/NiRotatingParticles.h"
		#include "obj/NiRotatingParticlesData.h"
		#include "obj/NiScreenLODData.h"
		#include "obj/NiSequenceStreamHelper.h"
		#include "obj/NiShadeProperty.h"
		#include "obj/NiSkinData.h"
		#include "obj/NiSkinInstance.h"
		#include "obj/NiSkinPartition.h"
		#include "obj/NiSourceTexture.h"
		#include "obj/NiSpecularProperty.h"
		#include "obj/NiSphericalCollider.h"
		#include "obj/NiSpotLight.h"
		#include "obj/NiStencilProperty.h"
		#include "obj/NiStringExtraData.h"
		#include "obj/NiStringPalette.h"
		#include "obj/NiStringsExtraData.h"
		#include "obj/NiTextKeyExtraData.h"
		#include "obj/NiTextureEffect.h"
		#include "obj/NiTextureTransformController.h"
		#include "obj/NiTexturingProperty.h"
		#include "obj/NiTransformController.h"
		#include "obj/NiTransformData.h"
		#include "obj/NiTransformInterpolator.h"
		#include "obj/NiTriShape.h"
		#include "obj/NiTriShapeData.h"
		#include "obj/NiTriStrips.h"
		#include "obj/NiTriStripsData.h"
		#include "obj/NiUVController.h"
		#include "obj/NiUVData.h"
		#include "obj/NiVectorExtraData.h"
		#include "obj/NiVertexColorProperty.h"
		#include "obj/NiVertWeightsExtraData.h"
		#include "obj/NiVisController.h"
		#include "obj/NiVisData.h"
		#include "obj/NiWireframeProperty.h"
		#include "obj/NiZBufferProperty.h"
		#include "obj/RootCollisionNode.h"
		#include "gen/ByteArray.h"
		#include "gen/Footer.h"
		#include "gen/LODRange.h"
		#include "gen/MatchGroup.h"
		#include "gen/MipMap.h"
		#include "gen/NodeGroup.h"
		#include "gen/QuaternionXYZW.h"
		#include "gen/ShortString.h"
		#include "gen/SkinShape.h"
		#include "gen/SkinShapeGroup.h"
		#include "gen/SkinWeight.h"
		#include "gen/AVObject.h"
		#include "gen/ControllerLink.h"
		#include "gen/Header.h"
		#include "gen/StringPalette.h"
		#include "gen/TBC.h"
		#include "gen/KeyGroup.h"
		#include "gen/RotationKeyArray.h"
		#include "gen/TexDesc.h"
		#include "gen/ShaderTexDesc.h"
		#include "gen/TexSource.h"
		#include "gen/SkinPartition.h"
		#include "gen/BoundingBox.h"
		#include "gen/FurniturePosition.h"
		#include "gen/hkTriangle.h"
		#include "gen/Morph.h"
		#include "gen/Particle.h"
		#include "gen/SkinData.h"
		#include "gen/RagDollDescriptor.h"
		#include "gen/LimitedHingeDescriptor.h"
%}


// we need the definition of the template classes before we define the template Python names below
template <class T> 
struct Key {
	float time;
	T data, forward_tangent, backward_tangent;
	float tension, bias, continuity;
};

%ignore Key;
%template(vector_byte) std::vector<byte>;
%template(vector_ushort) std::vector<ushort>;
%template(vector_SkinShape) std::vector<SkinShape>;
%template(vector_string) std::vector<std::string>;
%template(vector_Triangle) std::vector<Triangle>;
%template(vector_Vector3) std::vector<Vector3>;
%template(vector_float) std::vector<float>;
%template(vector_SkinWeight) std::vector<SkinWeight>;
%template(vector_NodeGroup) std::vector<NodeGroup>;
%template(vector_Color4) std::vector<Color4>;
%template(vector_Float4) std::vector<Float4>;
%template(vector_uint) std::vector<uint>;
%template(vector_FurniturePosition) std::vector<FurniturePosition>;
%template(vector_hkTriangle) std::vector<hkTriangle>;
%template(vector_SkinShapeGroup) std::vector<SkinShapeGroup>;
%template(vector_ControllerLink) std::vector<ControllerLink>;
%template(vector_AVObject) std::vector<AVObject>;
%template(vector_Morph) std::vector<Morph>;
%template(vector_LODRange) std::vector<LODRange>;
%template(vector_Quaternion) std::vector<Quaternion>;
%template(vector_Particle) std::vector<Particle>;
%template(vector_MipMap) std::vector<MipMap>;
%template(vector_SkinData) std::vector<SkinData>;
%template(vector_SkinPartition) std::vector<SkinPartition>;
%template(vector_ShaderTexDesc) std::vector<ShaderTexDesc>;
%template(vector_MatchGroup) std::vector<MatchGroup>;
%template(pair_int_float) std::pair<int, float>;
%template(map_int_float) std::map<int, float>;

%include "niflib.h"
%include "Ref.h"
%include "Type.h"
%include "nif_math.h"
%include "obj/NiObject.h"
%template(NiObjectRef) Ref<NiObject>;
%template(DynamicCastToNiObject) DynamicCast<NiObject>;
%template(StaticCastToNiObject) StaticCast<NiObject>;
%include "obj/AKeyedData.h"
%template(AKeyedDataRef) Ref<AKeyedData>;
%template(DynamicCastToAKeyedData) DynamicCast<AKeyedData>;
%template(StaticCastToAKeyedData) StaticCast<AKeyedData>;
%include "obj/AParticleModifier.h"
%template(AParticleModifierRef) Ref<AParticleModifier>;
%template(DynamicCastToAParticleModifier) DynamicCast<AParticleModifier>;
%template(StaticCastToAParticleModifier) StaticCast<AParticleModifier>;
%include "obj/bhkRefObject.h"
%template(bhkRefObjectRef) Ref<bhkRefObject>;
%template(DynamicCastTobhkRefObject) DynamicCast<bhkRefObject>;
%template(StaticCastTobhkRefObject) StaticCast<bhkRefObject>;
%include "obj/bhkSerializable.h"
%template(bhkSerializableRef) Ref<bhkSerializable>;
%template(DynamicCastTobhkSerializable) DynamicCast<bhkSerializable>;
%template(StaticCastTobhkSerializable) StaticCast<bhkSerializable>;
%include "obj/AbhkConstraint.h"
%template(AbhkConstraintRef) Ref<AbhkConstraint>;
%template(DynamicCastToAbhkConstraint) DynamicCast<AbhkConstraint>;
%template(StaticCastToAbhkConstraint) StaticCast<AbhkConstraint>;
%include "obj/AbhkRagdollConstraint.h"
%template(AbhkRagdollConstraintRef) Ref<AbhkRagdollConstraint>;
%template(DynamicCastToAbhkRagdollConstraint) DynamicCast<AbhkRagdollConstraint>;
%template(StaticCastToAbhkRagdollConstraint) StaticCast<AbhkRagdollConstraint>;
%include "obj/bhkShape.h"
%template(bhkShapeRef) Ref<bhkShape>;
%template(DynamicCastTobhkShape) DynamicCast<bhkShape>;
%template(StaticCastTobhkShape) StaticCast<bhkShape>;
%include "obj/AbhkShapeCollection.h"
%template(AbhkShapeCollectionRef) Ref<AbhkShapeCollection>;
%template(DynamicCastToAbhkShapeCollection) DynamicCast<AbhkShapeCollection>;
%template(StaticCastToAbhkShapeCollection) StaticCast<AbhkShapeCollection>;
%include "obj/bhkSphereRepShape.h"
%template(bhkSphereRepShapeRef) Ref<bhkSphereRepShape>;
%template(DynamicCastTobhkSphereRepShape) DynamicCast<bhkSphereRepShape>;
%template(StaticCastTobhkSphereRepShape) StaticCast<bhkSphereRepShape>;
%include "obj/bhkConvexShape.h"
%template(bhkConvexShapeRef) Ref<bhkConvexShape>;
%template(DynamicCastTobhkConvexShape) DynamicCast<bhkConvexShape>;
%template(StaticCastTobhkConvexShape) StaticCast<bhkConvexShape>;
%include "obj/bhkWorldObject.h"
%template(bhkWorldObjectRef) Ref<bhkWorldObject>;
%template(DynamicCastTobhkWorldObject) DynamicCast<bhkWorldObject>;
%template(StaticCastTobhkWorldObject) StaticCast<bhkWorldObject>;
%include "obj/bhkEntity.h"
%template(bhkEntityRef) Ref<bhkEntity>;
%template(DynamicCastTobhkEntity) DynamicCast<bhkEntity>;
%template(StaticCastTobhkEntity) StaticCast<bhkEntity>;
%include "obj/NiCollisionObject.h"
%template(NiCollisionObjectRef) Ref<NiCollisionObject>;
%template(DynamicCastToNiCollisionObject) DynamicCast<NiCollisionObject>;
%template(StaticCastToNiCollisionObject) StaticCast<NiCollisionObject>;
%include "obj/NiExtraData.h"
%template(NiExtraDataRef) Ref<NiExtraData>;
%template(DynamicCastToNiExtraData) DynamicCast<NiExtraData>;
%template(StaticCastToNiExtraData) StaticCast<NiExtraData>;
%include "obj/NiInterpolator.h"
%template(NiInterpolatorRef) Ref<NiInterpolator>;
%template(DynamicCastToNiInterpolator) DynamicCast<NiInterpolator>;
%template(StaticCastToNiInterpolator) StaticCast<NiInterpolator>;
%include "obj/NiBlendInterpolator.h"
%template(NiBlendInterpolatorRef) Ref<NiBlendInterpolator>;
%template(DynamicCastToNiBlendInterpolator) DynamicCast<NiBlendInterpolator>;
%template(StaticCastToNiBlendInterpolator) StaticCast<NiBlendInterpolator>;
%include "obj/NiBSplineInterpolator.h"
%template(NiBSplineInterpolatorRef) Ref<NiBSplineInterpolator>;
%template(DynamicCastToNiBSplineInterpolator) DynamicCast<NiBSplineInterpolator>;
%template(StaticCastToNiBSplineInterpolator) StaticCast<NiBSplineInterpolator>;
%include "obj/NiObjectNET.h"
%template(NiObjectNETRef) Ref<NiObjectNET>;
%template(DynamicCastToNiObjectNET) DynamicCast<NiObjectNET>;
%template(StaticCastToNiObjectNET) StaticCast<NiObjectNET>;
%include "obj/NiAVObject.h"
%template(NiAVObjectRef) Ref<NiAVObject>;
%template(DynamicCastToNiAVObject) DynamicCast<NiAVObject>;
%template(StaticCastToNiAVObject) StaticCast<NiAVObject>;
%include "obj/NiDynamicEffect.h"
%template(NiDynamicEffectRef) Ref<NiDynamicEffect>;
%template(DynamicCastToNiDynamicEffect) DynamicCast<NiDynamicEffect>;
%template(StaticCastToNiDynamicEffect) StaticCast<NiDynamicEffect>;
%include "obj/NiLight.h"
%template(NiLightRef) Ref<NiLight>;
%template(DynamicCastToNiLight) DynamicCast<NiLight>;
%template(StaticCastToNiLight) StaticCast<NiLight>;
%include "obj/NiProperty.h"
%template(NiPropertyRef) Ref<NiProperty>;
%template(DynamicCastToNiProperty) DynamicCast<NiProperty>;
%template(StaticCastToNiProperty) StaticCast<NiProperty>;
%include "obj/NiPSysModifier.h"
%template(NiPSysModifierRef) Ref<NiPSysModifier>;
%template(DynamicCastToNiPSysModifier) DynamicCast<NiPSysModifier>;
%template(StaticCastToNiPSysModifier) StaticCast<NiPSysModifier>;
%include "obj/NiPSysEmitter.h"
%template(NiPSysEmitterRef) Ref<NiPSysEmitter>;
%template(DynamicCastToNiPSysEmitter) DynamicCast<NiPSysEmitter>;
%template(StaticCastToNiPSysEmitter) StaticCast<NiPSysEmitter>;
%include "obj/NiPSysVolumeEmitter.h"
%template(NiPSysVolumeEmitterRef) Ref<NiPSysVolumeEmitter>;
%template(DynamicCastToNiPSysVolumeEmitter) DynamicCast<NiPSysVolumeEmitter>;
%template(StaticCastToNiPSysVolumeEmitter) StaticCast<NiPSysVolumeEmitter>;
%include "obj/NiTimeController.h"
%template(NiTimeControllerRef) Ref<NiTimeController>;
%template(DynamicCastToNiTimeController) DynamicCast<NiTimeController>;
%template(StaticCastToNiTimeController) StaticCast<NiTimeController>;
%include "obj/ABoneLODController.h"
%template(ABoneLODControllerRef) Ref<ABoneLODController>;
%template(DynamicCastToABoneLODController) DynamicCast<ABoneLODController>;
%template(StaticCastToABoneLODController) StaticCast<ABoneLODController>;
%include "obj/NiSingleInterpolatorController.h"
%template(NiSingleInterpolatorControllerRef) Ref<NiSingleInterpolatorController>;
%template(DynamicCastToNiSingleInterpolatorController) DynamicCast<NiSingleInterpolatorController>;
%template(StaticCastToNiSingleInterpolatorController) StaticCast<NiSingleInterpolatorController>;
%include "obj/APSysCtlr.h"
%template(APSysCtlrRef) Ref<APSysCtlr>;
%template(DynamicCastToAPSysCtlr) DynamicCast<APSysCtlr>;
%template(StaticCastToAPSysCtlr) StaticCast<APSysCtlr>;
%include "obj/NiTriBasedGeom.h"
%template(NiTriBasedGeomRef) Ref<NiTriBasedGeom>;
%template(DynamicCastToNiTriBasedGeom) DynamicCast<NiTriBasedGeom>;
%template(StaticCastToNiTriBasedGeom) StaticCast<NiTriBasedGeom>;
%include "obj/NiTriBasedGeomData.h"
%template(NiTriBasedGeomDataRef) Ref<NiTriBasedGeomData>;
%template(DynamicCastToNiTriBasedGeomData) DynamicCast<NiTriBasedGeomData>;
%template(StaticCastToNiTriBasedGeomData) StaticCast<NiTriBasedGeomData>;
%include "obj/APSysData.h"
%template(APSysDataRef) Ref<APSysData>;
%template(DynamicCastToAPSysData) DynamicCast<APSysData>;
%template(StaticCastToAPSysData) StaticCast<APSysData>;
%include "obj/bhkBlendCollisionObject.h"
%template(bhkBlendCollisionObjectRef) Ref<bhkBlendCollisionObject>;
%template(DynamicCastTobhkBlendCollisionObject) DynamicCast<bhkBlendCollisionObject>;
%template(StaticCastTobhkBlendCollisionObject) StaticCast<bhkBlendCollisionObject>;
%include "obj/bhkBlendController.h"
%template(bhkBlendControllerRef) Ref<bhkBlendController>;
%template(DynamicCastTobhkBlendController) DynamicCast<bhkBlendController>;
%template(StaticCastTobhkBlendController) StaticCast<bhkBlendController>;
%include "obj/bhkBoxShape.h"
%template(bhkBoxShapeRef) Ref<bhkBoxShape>;
%template(DynamicCastTobhkBoxShape) DynamicCast<bhkBoxShape>;
%template(StaticCastTobhkBoxShape) StaticCast<bhkBoxShape>;
%include "obj/bhkCapsuleShape.h"
%template(bhkCapsuleShapeRef) Ref<bhkCapsuleShape>;
%template(DynamicCastTobhkCapsuleShape) DynamicCast<bhkCapsuleShape>;
%template(StaticCastTobhkCapsuleShape) StaticCast<bhkCapsuleShape>;
%include "obj/bhkCollisionObject.h"
%template(bhkCollisionObjectRef) Ref<bhkCollisionObject>;
%template(DynamicCastTobhkCollisionObject) DynamicCast<bhkCollisionObject>;
%template(StaticCastTobhkCollisionObject) StaticCast<bhkCollisionObject>;
%include "obj/bhkConvexVerticesShape.h"
%template(bhkConvexVerticesShapeRef) Ref<bhkConvexVerticesShape>;
%template(DynamicCastTobhkConvexVerticesShape) DynamicCast<bhkConvexVerticesShape>;
%template(StaticCastTobhkConvexVerticesShape) StaticCast<bhkConvexVerticesShape>;
%include "obj/bhkHingeConstraint.h"
%template(bhkHingeConstraintRef) Ref<bhkHingeConstraint>;
%template(DynamicCastTobhkHingeConstraint) DynamicCast<bhkHingeConstraint>;
%template(StaticCastTobhkHingeConstraint) StaticCast<bhkHingeConstraint>;
%include "obj/bhkLimitedHingeConstraint.h"
%template(bhkLimitedHingeConstraintRef) Ref<bhkLimitedHingeConstraint>;
%template(DynamicCastTobhkLimitedHingeConstraint) DynamicCast<bhkLimitedHingeConstraint>;
%template(StaticCastTobhkLimitedHingeConstraint) StaticCast<bhkLimitedHingeConstraint>;
%include "obj/bhkListShape.h"
%template(bhkListShapeRef) Ref<bhkListShape>;
%template(DynamicCastTobhkListShape) DynamicCast<bhkListShape>;
%template(StaticCastTobhkListShape) StaticCast<bhkListShape>;
%include "obj/bhkMalleableConstraint.h"
%template(bhkMalleableConstraintRef) Ref<bhkMalleableConstraint>;
%template(DynamicCastTobhkMalleableConstraint) DynamicCast<bhkMalleableConstraint>;
%template(StaticCastTobhkMalleableConstraint) StaticCast<bhkMalleableConstraint>;
%include "obj/bhkMoppBvTreeShape.h"
%template(bhkMoppBvTreeShapeRef) Ref<bhkMoppBvTreeShape>;
%template(DynamicCastTobhkMoppBvTreeShape) DynamicCast<bhkMoppBvTreeShape>;
%template(StaticCastTobhkMoppBvTreeShape) StaticCast<bhkMoppBvTreeShape>;
%include "obj/bhkMultiSphereShape.h"
%template(bhkMultiSphereShapeRef) Ref<bhkMultiSphereShape>;
%template(DynamicCastTobhkMultiSphereShape) DynamicCast<bhkMultiSphereShape>;
%template(StaticCastTobhkMultiSphereShape) StaticCast<bhkMultiSphereShape>;
%include "obj/bhkNiTriStripsShape.h"
%template(bhkNiTriStripsShapeRef) Ref<bhkNiTriStripsShape>;
%template(DynamicCastTobhkNiTriStripsShape) DynamicCast<bhkNiTriStripsShape>;
%template(StaticCastTobhkNiTriStripsShape) StaticCast<bhkNiTriStripsShape>;
%include "obj/bhkPackedNiTriStripsShape.h"
%template(bhkPackedNiTriStripsShapeRef) Ref<bhkPackedNiTriStripsShape>;
%template(DynamicCastTobhkPackedNiTriStripsShape) DynamicCast<bhkPackedNiTriStripsShape>;
%template(StaticCastTobhkPackedNiTriStripsShape) StaticCast<bhkPackedNiTriStripsShape>;
%include "obj/bhkPrismaticConstraint.h"
%template(bhkPrismaticConstraintRef) Ref<bhkPrismaticConstraint>;
%template(DynamicCastTobhkPrismaticConstraint) DynamicCast<bhkPrismaticConstraint>;
%template(StaticCastTobhkPrismaticConstraint) StaticCast<bhkPrismaticConstraint>;
%include "obj/bhkRagdollConstraint.h"
%template(bhkRagdollConstraintRef) Ref<bhkRagdollConstraint>;
%template(DynamicCastTobhkRagdollConstraint) DynamicCast<bhkRagdollConstraint>;
%template(StaticCastTobhkRagdollConstraint) StaticCast<bhkRagdollConstraint>;
%include "obj/bhkRigidBody.h"
%template(bhkRigidBodyRef) Ref<bhkRigidBody>;
%template(DynamicCastTobhkRigidBody) DynamicCast<bhkRigidBody>;
%template(StaticCastTobhkRigidBody) StaticCast<bhkRigidBody>;
%include "obj/bhkRigidBodyT.h"
%template(bhkRigidBodyTRef) Ref<bhkRigidBodyT>;
%template(DynamicCastTobhkRigidBodyT) DynamicCast<bhkRigidBodyT>;
%template(StaticCastTobhkRigidBodyT) StaticCast<bhkRigidBodyT>;
%include "obj/bhkSimpleShapePhantom.h"
%template(bhkSimpleShapePhantomRef) Ref<bhkSimpleShapePhantom>;
%template(DynamicCastTobhkSimpleShapePhantom) DynamicCast<bhkSimpleShapePhantom>;
%template(StaticCastTobhkSimpleShapePhantom) StaticCast<bhkSimpleShapePhantom>;
%include "obj/bhkSPCollisionObject.h"
%template(bhkSPCollisionObjectRef) Ref<bhkSPCollisionObject>;
%template(DynamicCastTobhkSPCollisionObject) DynamicCast<bhkSPCollisionObject>;
%template(StaticCastTobhkSPCollisionObject) StaticCast<bhkSPCollisionObject>;
%include "obj/bhkSphereShape.h"
%template(bhkSphereShapeRef) Ref<bhkSphereShape>;
%template(DynamicCastTobhkSphereShape) DynamicCast<bhkSphereShape>;
%template(StaticCastTobhkSphereShape) StaticCast<bhkSphereShape>;
%include "obj/bhkStiffSpringConstraint.h"
%template(bhkStiffSpringConstraintRef) Ref<bhkStiffSpringConstraint>;
%template(DynamicCastTobhkStiffSpringConstraint) DynamicCast<bhkStiffSpringConstraint>;
%template(StaticCastTobhkStiffSpringConstraint) StaticCast<bhkStiffSpringConstraint>;
%include "obj/bhkTransformShape.h"
%template(bhkTransformShapeRef) Ref<bhkTransformShape>;
%template(DynamicCastTobhkTransformShape) DynamicCast<bhkTransformShape>;
%template(StaticCastTobhkTransformShape) StaticCast<bhkTransformShape>;
%include "obj/bhkConvexTransformShape.h"
%template(bhkConvexTransformShapeRef) Ref<bhkConvexTransformShape>;
%template(DynamicCastTobhkConvexTransformShape) DynamicCast<bhkConvexTransformShape>;
%template(StaticCastTobhkConvexTransformShape) StaticCast<bhkConvexTransformShape>;
%include "obj/BSBound.h"
%template(BSBoundRef) Ref<BSBound>;
%template(DynamicCastToBSBound) DynamicCast<BSBound>;
%template(StaticCastToBSBound) StaticCast<BSBound>;
%include "obj/BSFurnitureMarker.h"
%template(BSFurnitureMarkerRef) Ref<BSFurnitureMarker>;
%template(DynamicCastToBSFurnitureMarker) DynamicCast<BSFurnitureMarker>;
%template(StaticCastToBSFurnitureMarker) StaticCast<BSFurnitureMarker>;
%include "obj/BSParentVelocityModifier.h"
%template(BSParentVelocityModifierRef) Ref<BSParentVelocityModifier>;
%template(DynamicCastToBSParentVelocityModifier) DynamicCast<BSParentVelocityModifier>;
%template(StaticCastToBSParentVelocityModifier) StaticCast<BSParentVelocityModifier>;
%include "obj/BSPSysArrayEmitter.h"
%template(BSPSysArrayEmitterRef) Ref<BSPSysArrayEmitter>;
%template(DynamicCastToBSPSysArrayEmitter) DynamicCast<BSPSysArrayEmitter>;
%template(StaticCastToBSPSysArrayEmitter) StaticCast<BSPSysArrayEmitter>;
%include "obj/BSXFlags.h"
%template(BSXFlagsRef) Ref<BSXFlags>;
%template(DynamicCastToBSXFlags) DynamicCast<BSXFlags>;
%template(StaticCastToBSXFlags) StaticCast<BSXFlags>;
%include "obj/hkPackedNiTriStripsData.h"
%template(hkPackedNiTriStripsDataRef) Ref<hkPackedNiTriStripsData>;
%template(DynamicCastTohkPackedNiTriStripsData) DynamicCast<hkPackedNiTriStripsData>;
%template(StaticCastTohkPackedNiTriStripsData) StaticCast<hkPackedNiTriStripsData>;
%include "obj/NiAlphaController.h"
%template(NiAlphaControllerRef) Ref<NiAlphaController>;
%template(DynamicCastToNiAlphaController) DynamicCast<NiAlphaController>;
%template(StaticCastToNiAlphaController) StaticCast<NiAlphaController>;
%include "obj/NiAlphaProperty.h"
%template(NiAlphaPropertyRef) Ref<NiAlphaProperty>;
%template(DynamicCastToNiAlphaProperty) DynamicCast<NiAlphaProperty>;
%template(StaticCastToNiAlphaProperty) StaticCast<NiAlphaProperty>;
%include "obj/NiAmbientLight.h"
%template(NiAmbientLightRef) Ref<NiAmbientLight>;
%template(DynamicCastToNiAmbientLight) DynamicCast<NiAmbientLight>;
%template(StaticCastToNiAmbientLight) StaticCast<NiAmbientLight>;
%include "obj/NiAutoNormalParticlesData.h"
%template(NiAutoNormalParticlesDataRef) Ref<NiAutoNormalParticlesData>;
%template(DynamicCastToNiAutoNormalParticlesData) DynamicCast<NiAutoNormalParticlesData>;
%template(StaticCastToNiAutoNormalParticlesData) StaticCast<NiAutoNormalParticlesData>;
%include "obj/NiBinaryExtraData.h"
%template(NiBinaryExtraDataRef) Ref<NiBinaryExtraData>;
%template(DynamicCastToNiBinaryExtraData) DynamicCast<NiBinaryExtraData>;
%template(StaticCastToNiBinaryExtraData) StaticCast<NiBinaryExtraData>;
%include "obj/NiBlendBoolInterpolator.h"
%template(NiBlendBoolInterpolatorRef) Ref<NiBlendBoolInterpolator>;
%template(DynamicCastToNiBlendBoolInterpolator) DynamicCast<NiBlendBoolInterpolator>;
%template(StaticCastToNiBlendBoolInterpolator) StaticCast<NiBlendBoolInterpolator>;
%include "obj/NiBlendFloatInterpolator.h"
%template(NiBlendFloatInterpolatorRef) Ref<NiBlendFloatInterpolator>;
%template(DynamicCastToNiBlendFloatInterpolator) DynamicCast<NiBlendFloatInterpolator>;
%template(StaticCastToNiBlendFloatInterpolator) StaticCast<NiBlendFloatInterpolator>;
%include "obj/NiBlendPoint3Interpolator.h"
%template(NiBlendPoint3InterpolatorRef) Ref<NiBlendPoint3Interpolator>;
%template(DynamicCastToNiBlendPoint3Interpolator) DynamicCast<NiBlendPoint3Interpolator>;
%template(StaticCastToNiBlendPoint3Interpolator) StaticCast<NiBlendPoint3Interpolator>;
%include "obj/NiBlendTransformInterpolator.h"
%template(NiBlendTransformInterpolatorRef) Ref<NiBlendTransformInterpolator>;
%template(DynamicCastToNiBlendTransformInterpolator) DynamicCast<NiBlendTransformInterpolator>;
%template(StaticCastToNiBlendTransformInterpolator) StaticCast<NiBlendTransformInterpolator>;
%include "obj/NiBoneLODController.h"
%template(NiBoneLODControllerRef) Ref<NiBoneLODController>;
%template(DynamicCastToNiBoneLODController) DynamicCast<NiBoneLODController>;
%template(StaticCastToNiBoneLODController) StaticCast<NiBoneLODController>;
%include "obj/NiBoolData.h"
%template(NiBoolDataRef) Ref<NiBoolData>;
%template(DynamicCastToNiBoolData) DynamicCast<NiBoolData>;
%template(StaticCastToNiBoolData) StaticCast<NiBoolData>;
%include "obj/NiBooleanExtraData.h"
%template(NiBooleanExtraDataRef) Ref<NiBooleanExtraData>;
%template(DynamicCastToNiBooleanExtraData) DynamicCast<NiBooleanExtraData>;
%template(StaticCastToNiBooleanExtraData) StaticCast<NiBooleanExtraData>;
%include "obj/NiBoolInterpolator.h"
%template(NiBoolInterpolatorRef) Ref<NiBoolInterpolator>;
%template(DynamicCastToNiBoolInterpolator) DynamicCast<NiBoolInterpolator>;
%template(StaticCastToNiBoolInterpolator) StaticCast<NiBoolInterpolator>;
%include "obj/NiBoolTimelineInterpolator.h"
%template(NiBoolTimelineInterpolatorRef) Ref<NiBoolTimelineInterpolator>;
%template(DynamicCastToNiBoolTimelineInterpolator) DynamicCast<NiBoolTimelineInterpolator>;
%template(StaticCastToNiBoolTimelineInterpolator) StaticCast<NiBoolTimelineInterpolator>;
%include "obj/NiBSBoneLODController.h"
%template(NiBSBoneLODControllerRef) Ref<NiBSBoneLODController>;
%template(DynamicCastToNiBSBoneLODController) DynamicCast<NiBSBoneLODController>;
%template(StaticCastToNiBSBoneLODController) StaticCast<NiBSBoneLODController>;
%include "obj/NiBSplineBasisData.h"
%template(NiBSplineBasisDataRef) Ref<NiBSplineBasisData>;
%template(DynamicCastToNiBSplineBasisData) DynamicCast<NiBSplineBasisData>;
%template(StaticCastToNiBSplineBasisData) StaticCast<NiBSplineBasisData>;
%include "obj/NiBSplineCompFloatInterpolator.h"
%template(NiBSplineCompFloatInterpolatorRef) Ref<NiBSplineCompFloatInterpolator>;
%template(DynamicCastToNiBSplineCompFloatInterpolator) DynamicCast<NiBSplineCompFloatInterpolator>;
%template(StaticCastToNiBSplineCompFloatInterpolator) StaticCast<NiBSplineCompFloatInterpolator>;
%include "obj/NiBSplineCompPoint3Interpolator.h"
%template(NiBSplineCompPoint3InterpolatorRef) Ref<NiBSplineCompPoint3Interpolator>;
%template(DynamicCastToNiBSplineCompPoint3Interpolator) DynamicCast<NiBSplineCompPoint3Interpolator>;
%template(StaticCastToNiBSplineCompPoint3Interpolator) StaticCast<NiBSplineCompPoint3Interpolator>;
%include "obj/NiBSplineCompTransformInterpolator.h"
%template(NiBSplineCompTransformInterpolatorRef) Ref<NiBSplineCompTransformInterpolator>;
%template(DynamicCastToNiBSplineCompTransformInterpolator) DynamicCast<NiBSplineCompTransformInterpolator>;
%template(StaticCastToNiBSplineCompTransformInterpolator) StaticCast<NiBSplineCompTransformInterpolator>;
%include "obj/NiBSplineData.h"
%template(NiBSplineDataRef) Ref<NiBSplineData>;
%template(DynamicCastToNiBSplineData) DynamicCast<NiBSplineData>;
%template(StaticCastToNiBSplineData) StaticCast<NiBSplineData>;
%include "obj/NiCamera.h"
%template(NiCameraRef) Ref<NiCamera>;
%template(DynamicCastToNiCamera) DynamicCast<NiCamera>;
%template(StaticCastToNiCamera) StaticCast<NiCamera>;
%include "obj/NiCollisionData.h"
%template(NiCollisionDataRef) Ref<NiCollisionData>;
%template(DynamicCastToNiCollisionData) DynamicCast<NiCollisionData>;
%template(StaticCastToNiCollisionData) StaticCast<NiCollisionData>;
%include "obj/NiColorData.h"
%template(NiColorDataRef) Ref<NiColorData>;
%template(DynamicCastToNiColorData) DynamicCast<NiColorData>;
%template(StaticCastToNiColorData) StaticCast<NiColorData>;
%include "obj/NiColorExtraData.h"
%template(NiColorExtraDataRef) Ref<NiColorExtraData>;
%template(DynamicCastToNiColorExtraData) DynamicCast<NiColorExtraData>;
%template(StaticCastToNiColorExtraData) StaticCast<NiColorExtraData>;
%include "obj/NiControllerManager.h"
%template(NiControllerManagerRef) Ref<NiControllerManager>;
%template(DynamicCastToNiControllerManager) DynamicCast<NiControllerManager>;
%template(StaticCastToNiControllerManager) StaticCast<NiControllerManager>;
%include "obj/NiControllerSequence.h"
%template(NiControllerSequenceRef) Ref<NiControllerSequence>;
%template(DynamicCastToNiControllerSequence) DynamicCast<NiControllerSequence>;
%template(StaticCastToNiControllerSequence) StaticCast<NiControllerSequence>;
%include "obj/NiDefaultAVObjectPalette.h"
%template(NiDefaultAVObjectPaletteRef) Ref<NiDefaultAVObjectPalette>;
%template(DynamicCastToNiDefaultAVObjectPalette) DynamicCast<NiDefaultAVObjectPalette>;
%template(StaticCastToNiDefaultAVObjectPalette) StaticCast<NiDefaultAVObjectPalette>;
%include "obj/NiDirectionalLight.h"
%template(NiDirectionalLightRef) Ref<NiDirectionalLight>;
%template(DynamicCastToNiDirectionalLight) DynamicCast<NiDirectionalLight>;
%template(StaticCastToNiDirectionalLight) StaticCast<NiDirectionalLight>;
%include "obj/NiDitherProperty.h"
%template(NiDitherPropertyRef) Ref<NiDitherProperty>;
%template(DynamicCastToNiDitherProperty) DynamicCast<NiDitherProperty>;
%template(StaticCastToNiDitherProperty) StaticCast<NiDitherProperty>;
%include "obj/NiFlipController.h"
%template(NiFlipControllerRef) Ref<NiFlipController>;
%template(DynamicCastToNiFlipController) DynamicCast<NiFlipController>;
%template(StaticCastToNiFlipController) StaticCast<NiFlipController>;
%include "obj/NiFloatData.h"
%template(NiFloatDataRef) Ref<NiFloatData>;
%template(DynamicCastToNiFloatData) DynamicCast<NiFloatData>;
%template(StaticCastToNiFloatData) StaticCast<NiFloatData>;
%include "obj/NiFloatExtraData.h"
%template(NiFloatExtraDataRef) Ref<NiFloatExtraData>;
%template(DynamicCastToNiFloatExtraData) DynamicCast<NiFloatExtraData>;
%template(StaticCastToNiFloatExtraData) StaticCast<NiFloatExtraData>;
%include "obj/NiFloatExtraDataController.h"
%template(NiFloatExtraDataControllerRef) Ref<NiFloatExtraDataController>;
%template(DynamicCastToNiFloatExtraDataController) DynamicCast<NiFloatExtraDataController>;
%template(StaticCastToNiFloatExtraDataController) StaticCast<NiFloatExtraDataController>;
%include "obj/NiFloatInterpolator.h"
%template(NiFloatInterpolatorRef) Ref<NiFloatInterpolator>;
%template(DynamicCastToNiFloatInterpolator) DynamicCast<NiFloatInterpolator>;
%template(StaticCastToNiFloatInterpolator) StaticCast<NiFloatInterpolator>;
%include "obj/NiFloatsExtraData.h"
%template(NiFloatsExtraDataRef) Ref<NiFloatsExtraData>;
%template(DynamicCastToNiFloatsExtraData) DynamicCast<NiFloatsExtraData>;
%template(StaticCastToNiFloatsExtraData) StaticCast<NiFloatsExtraData>;
%include "obj/NiFogProperty.h"
%template(NiFogPropertyRef) Ref<NiFogProperty>;
%template(DynamicCastToNiFogProperty) DynamicCast<NiFogProperty>;
%template(StaticCastToNiFogProperty) StaticCast<NiFogProperty>;
%include "obj/NiGeomMorpherController.h"
%template(NiGeomMorpherControllerRef) Ref<NiGeomMorpherController>;
%template(DynamicCastToNiGeomMorpherController) DynamicCast<NiGeomMorpherController>;
%template(StaticCastToNiGeomMorpherController) StaticCast<NiGeomMorpherController>;
%include "obj/NiGravity.h"
%template(NiGravityRef) Ref<NiGravity>;
%template(DynamicCastToNiGravity) DynamicCast<NiGravity>;
%template(StaticCastToNiGravity) StaticCast<NiGravity>;
%include "obj/NiIntegerExtraData.h"
%template(NiIntegerExtraDataRef) Ref<NiIntegerExtraData>;
%template(DynamicCastToNiIntegerExtraData) DynamicCast<NiIntegerExtraData>;
%template(StaticCastToNiIntegerExtraData) StaticCast<NiIntegerExtraData>;
%include "obj/NiIntegersExtraData.h"
%template(NiIntegersExtraDataRef) Ref<NiIntegersExtraData>;
%template(DynamicCastToNiIntegersExtraData) DynamicCast<NiIntegersExtraData>;
%template(StaticCastToNiIntegersExtraData) StaticCast<NiIntegersExtraData>;
%include "obj/NiKeyframeController.h"
%template(NiKeyframeControllerRef) Ref<NiKeyframeController>;
%template(DynamicCastToNiKeyframeController) DynamicCast<NiKeyframeController>;
%template(StaticCastToNiKeyframeController) StaticCast<NiKeyframeController>;
%include "obj/BSKeyframeController.h"
%template(BSKeyframeControllerRef) Ref<BSKeyframeController>;
%template(DynamicCastToBSKeyframeController) DynamicCast<BSKeyframeController>;
%template(StaticCastToBSKeyframeController) StaticCast<BSKeyframeController>;
%include "obj/NiKeyframeData.h"
%template(NiKeyframeDataRef) Ref<NiKeyframeData>;
%template(DynamicCastToNiKeyframeData) DynamicCast<NiKeyframeData>;
%template(StaticCastToNiKeyframeData) StaticCast<NiKeyframeData>;
%include "obj/NiLightColorController.h"
%template(NiLightColorControllerRef) Ref<NiLightColorController>;
%template(DynamicCastToNiLightColorController) DynamicCast<NiLightColorController>;
%template(StaticCastToNiLightColorController) StaticCast<NiLightColorController>;
%include "obj/NiLightDimmerController.h"
%template(NiLightDimmerControllerRef) Ref<NiLightDimmerController>;
%template(DynamicCastToNiLightDimmerController) DynamicCast<NiLightDimmerController>;
%template(StaticCastToNiLightDimmerController) StaticCast<NiLightDimmerController>;
%include "obj/NiLookAtController.h"
%template(NiLookAtControllerRef) Ref<NiLookAtController>;
%template(DynamicCastToNiLookAtController) DynamicCast<NiLookAtController>;
%template(StaticCastToNiLookAtController) StaticCast<NiLookAtController>;
%include "obj/NiLookAtInterpolator.h"
%template(NiLookAtInterpolatorRef) Ref<NiLookAtInterpolator>;
%template(DynamicCastToNiLookAtInterpolator) DynamicCast<NiLookAtInterpolator>;
%template(StaticCastToNiLookAtInterpolator) StaticCast<NiLookAtInterpolator>;
%include "obj/NiMaterialColorController.h"
%template(NiMaterialColorControllerRef) Ref<NiMaterialColorController>;
%template(DynamicCastToNiMaterialColorController) DynamicCast<NiMaterialColorController>;
%template(StaticCastToNiMaterialColorController) StaticCast<NiMaterialColorController>;
%include "obj/NiMaterialProperty.h"
%template(NiMaterialPropertyRef) Ref<NiMaterialProperty>;
%template(DynamicCastToNiMaterialProperty) DynamicCast<NiMaterialProperty>;
%template(StaticCastToNiMaterialProperty) StaticCast<NiMaterialProperty>;
%include "obj/NiMeshPSysData.h"
%template(NiMeshPSysDataRef) Ref<NiMeshPSysData>;
%template(DynamicCastToNiMeshPSysData) DynamicCast<NiMeshPSysData>;
%template(StaticCastToNiMeshPSysData) StaticCast<NiMeshPSysData>;
%include "obj/NiMorphData.h"
%template(NiMorphDataRef) Ref<NiMorphData>;
%template(DynamicCastToNiMorphData) DynamicCast<NiMorphData>;
%template(StaticCastToNiMorphData) StaticCast<NiMorphData>;
%include "obj/NiMultiTargetTransformController.h"
%template(NiMultiTargetTransformControllerRef) Ref<NiMultiTargetTransformController>;
%template(DynamicCastToNiMultiTargetTransformController) DynamicCast<NiMultiTargetTransformController>;
%template(StaticCastToNiMultiTargetTransformController) StaticCast<NiMultiTargetTransformController>;
%include "obj/NiNode.h"
%template(NiNodeRef) Ref<NiNode>;
%template(DynamicCastToNiNode) DynamicCast<NiNode>;
%template(StaticCastToNiNode) StaticCast<NiNode>;
%include "obj/AvoidNode.h"
%template(AvoidNodeRef) Ref<AvoidNode>;
%template(DynamicCastToAvoidNode) DynamicCast<AvoidNode>;
%template(StaticCastToAvoidNode) StaticCast<AvoidNode>;
%include "obj/FxWidget.h"
%template(FxWidgetRef) Ref<FxWidget>;
%template(DynamicCastToFxWidget) DynamicCast<FxWidget>;
%template(StaticCastToFxWidget) StaticCast<FxWidget>;
%include "obj/FxButton.h"
%template(FxButtonRef) Ref<FxButton>;
%template(DynamicCastToFxButton) DynamicCast<FxButton>;
%template(StaticCastToFxButton) StaticCast<FxButton>;
%include "obj/FxRadioButton.h"
%template(FxRadioButtonRef) Ref<FxRadioButton>;
%template(DynamicCastToFxRadioButton) DynamicCast<FxRadioButton>;
%template(StaticCastToFxRadioButton) StaticCast<FxRadioButton>;
%include "obj/NiBillboardNode.h"
%template(NiBillboardNodeRef) Ref<NiBillboardNode>;
%template(DynamicCastToNiBillboardNode) DynamicCast<NiBillboardNode>;
%template(StaticCastToNiBillboardNode) StaticCast<NiBillboardNode>;
%include "obj/NiBSAnimationNode.h"
%template(NiBSAnimationNodeRef) Ref<NiBSAnimationNode>;
%template(DynamicCastToNiBSAnimationNode) DynamicCast<NiBSAnimationNode>;
%template(StaticCastToNiBSAnimationNode) StaticCast<NiBSAnimationNode>;
%include "obj/NiBSParticleNode.h"
%template(NiBSParticleNodeRef) Ref<NiBSParticleNode>;
%template(DynamicCastToNiBSParticleNode) DynamicCast<NiBSParticleNode>;
%template(StaticCastToNiBSParticleNode) StaticCast<NiBSParticleNode>;
%include "obj/NiLODNode.h"
%template(NiLODNodeRef) Ref<NiLODNode>;
%template(DynamicCastToNiLODNode) DynamicCast<NiLODNode>;
%template(StaticCastToNiLODNode) StaticCast<NiLODNode>;
%include "obj/NiPalette.h"
%template(NiPaletteRef) Ref<NiPalette>;
%template(DynamicCastToNiPalette) DynamicCast<NiPalette>;
%template(StaticCastToNiPalette) StaticCast<NiPalette>;
%include "obj/NiParticleBomb.h"
%template(NiParticleBombRef) Ref<NiParticleBomb>;
%template(DynamicCastToNiParticleBomb) DynamicCast<NiParticleBomb>;
%template(StaticCastToNiParticleBomb) StaticCast<NiParticleBomb>;
%include "obj/NiParticleColorModifier.h"
%template(NiParticleColorModifierRef) Ref<NiParticleColorModifier>;
%template(DynamicCastToNiParticleColorModifier) DynamicCast<NiParticleColorModifier>;
%template(StaticCastToNiParticleColorModifier) StaticCast<NiParticleColorModifier>;
%include "obj/NiParticleGrowFade.h"
%template(NiParticleGrowFadeRef) Ref<NiParticleGrowFade>;
%template(DynamicCastToNiParticleGrowFade) DynamicCast<NiParticleGrowFade>;
%template(StaticCastToNiParticleGrowFade) StaticCast<NiParticleGrowFade>;
%include "obj/NiParticleMeshModifier.h"
%template(NiParticleMeshModifierRef) Ref<NiParticleMeshModifier>;
%template(DynamicCastToNiParticleMeshModifier) DynamicCast<NiParticleMeshModifier>;
%template(StaticCastToNiParticleMeshModifier) StaticCast<NiParticleMeshModifier>;
%include "obj/NiParticleRotation.h"
%template(NiParticleRotationRef) Ref<NiParticleRotation>;
%template(DynamicCastToNiParticleRotation) DynamicCast<NiParticleRotation>;
%template(StaticCastToNiParticleRotation) StaticCast<NiParticleRotation>;
%include "obj/NiParticles.h"
%template(NiParticlesRef) Ref<NiParticles>;
%template(DynamicCastToNiParticles) DynamicCast<NiParticles>;
%template(StaticCastToNiParticles) StaticCast<NiParticles>;
%include "obj/NiAutoNormalParticles.h"
%template(NiAutoNormalParticlesRef) Ref<NiAutoNormalParticles>;
%template(DynamicCastToNiAutoNormalParticles) DynamicCast<NiAutoNormalParticles>;
%template(StaticCastToNiAutoNormalParticles) StaticCast<NiAutoNormalParticles>;
%include "obj/NiParticleMeshes.h"
%template(NiParticleMeshesRef) Ref<NiParticleMeshes>;
%template(DynamicCastToNiParticleMeshes) DynamicCast<NiParticleMeshes>;
%template(StaticCastToNiParticleMeshes) StaticCast<NiParticleMeshes>;
%include "obj/NiParticlesData.h"
%template(NiParticlesDataRef) Ref<NiParticlesData>;
%template(DynamicCastToNiParticlesData) DynamicCast<NiParticlesData>;
%template(StaticCastToNiParticlesData) StaticCast<NiParticlesData>;
%include "obj/NiParticleMeshesData.h"
%template(NiParticleMeshesDataRef) Ref<NiParticleMeshesData>;
%template(DynamicCastToNiParticleMeshesData) DynamicCast<NiParticleMeshesData>;
%template(StaticCastToNiParticleMeshesData) StaticCast<NiParticleMeshesData>;
%include "obj/NiParticleSystem.h"
%template(NiParticleSystemRef) Ref<NiParticleSystem>;
%template(DynamicCastToNiParticleSystem) DynamicCast<NiParticleSystem>;
%template(StaticCastToNiParticleSystem) StaticCast<NiParticleSystem>;
%include "obj/NiMeshParticleSystem.h"
%template(NiMeshParticleSystemRef) Ref<NiMeshParticleSystem>;
%template(DynamicCastToNiMeshParticleSystem) DynamicCast<NiMeshParticleSystem>;
%template(StaticCastToNiMeshParticleSystem) StaticCast<NiMeshParticleSystem>;
%include "obj/NiParticleSystemController.h"
%template(NiParticleSystemControllerRef) Ref<NiParticleSystemController>;
%template(DynamicCastToNiParticleSystemController) DynamicCast<NiParticleSystemController>;
%template(StaticCastToNiParticleSystemController) StaticCast<NiParticleSystemController>;
%include "obj/NiBSPArrayController.h"
%template(NiBSPArrayControllerRef) Ref<NiBSPArrayController>;
%template(DynamicCastToNiBSPArrayController) DynamicCast<NiBSPArrayController>;
%template(StaticCastToNiBSPArrayController) StaticCast<NiBSPArrayController>;
%include "obj/NiPathController.h"
%template(NiPathControllerRef) Ref<NiPathController>;
%template(DynamicCastToNiPathController) DynamicCast<NiPathController>;
%template(StaticCastToNiPathController) StaticCast<NiPathController>;
%include "obj/NiPathInterpolator.h"
%template(NiPathInterpolatorRef) Ref<NiPathInterpolator>;
%template(DynamicCastToNiPathInterpolator) DynamicCast<NiPathInterpolator>;
%template(StaticCastToNiPathInterpolator) StaticCast<NiPathInterpolator>;
%include "obj/NiPixelData.h"
%template(NiPixelDataRef) Ref<NiPixelData>;
%template(DynamicCastToNiPixelData) DynamicCast<NiPixelData>;
%template(StaticCastToNiPixelData) StaticCast<NiPixelData>;
%include "obj/NiPlanarCollider.h"
%template(NiPlanarColliderRef) Ref<NiPlanarCollider>;
%template(DynamicCastToNiPlanarCollider) DynamicCast<NiPlanarCollider>;
%template(StaticCastToNiPlanarCollider) StaticCast<NiPlanarCollider>;
%include "obj/NiPoint3Interpolator.h"
%template(NiPoint3InterpolatorRef) Ref<NiPoint3Interpolator>;
%template(DynamicCastToNiPoint3Interpolator) DynamicCast<NiPoint3Interpolator>;
%template(StaticCastToNiPoint3Interpolator) StaticCast<NiPoint3Interpolator>;
%include "obj/NiPointLight.h"
%template(NiPointLightRef) Ref<NiPointLight>;
%template(DynamicCastToNiPointLight) DynamicCast<NiPointLight>;
%template(StaticCastToNiPointLight) StaticCast<NiPointLight>;
%include "obj/NiPosData.h"
%template(NiPosDataRef) Ref<NiPosData>;
%template(DynamicCastToNiPosData) DynamicCast<NiPosData>;
%template(StaticCastToNiPosData) StaticCast<NiPosData>;
%include "obj/NiPSysAgeDeathModifier.h"
%template(NiPSysAgeDeathModifierRef) Ref<NiPSysAgeDeathModifier>;
%template(DynamicCastToNiPSysAgeDeathModifier) DynamicCast<NiPSysAgeDeathModifier>;
%template(StaticCastToNiPSysAgeDeathModifier) StaticCast<NiPSysAgeDeathModifier>;
%include "obj/NiPSysBombModifier.h"
%template(NiPSysBombModifierRef) Ref<NiPSysBombModifier>;
%template(DynamicCastToNiPSysBombModifier) DynamicCast<NiPSysBombModifier>;
%template(StaticCastToNiPSysBombModifier) StaticCast<NiPSysBombModifier>;
%include "obj/NiPSysBoundUpdateModifier.h"
%template(NiPSysBoundUpdateModifierRef) Ref<NiPSysBoundUpdateModifier>;
%template(DynamicCastToNiPSysBoundUpdateModifier) DynamicCast<NiPSysBoundUpdateModifier>;
%template(StaticCastToNiPSysBoundUpdateModifier) StaticCast<NiPSysBoundUpdateModifier>;
%include "obj/NiPSysBoxEmitter.h"
%template(NiPSysBoxEmitterRef) Ref<NiPSysBoxEmitter>;
%template(DynamicCastToNiPSysBoxEmitter) DynamicCast<NiPSysBoxEmitter>;
%template(StaticCastToNiPSysBoxEmitter) StaticCast<NiPSysBoxEmitter>;
%include "obj/NiPSysColliderManager.h"
%template(NiPSysColliderManagerRef) Ref<NiPSysColliderManager>;
%template(DynamicCastToNiPSysColliderManager) DynamicCast<NiPSysColliderManager>;
%template(StaticCastToNiPSysColliderManager) StaticCast<NiPSysColliderManager>;
%include "obj/NiPSysColorModifier.h"
%template(NiPSysColorModifierRef) Ref<NiPSysColorModifier>;
%template(DynamicCastToNiPSysColorModifier) DynamicCast<NiPSysColorModifier>;
%template(StaticCastToNiPSysColorModifier) StaticCast<NiPSysColorModifier>;
%include "obj/NiPSysCylinderEmitter.h"
%template(NiPSysCylinderEmitterRef) Ref<NiPSysCylinderEmitter>;
%template(DynamicCastToNiPSysCylinderEmitter) DynamicCast<NiPSysCylinderEmitter>;
%template(StaticCastToNiPSysCylinderEmitter) StaticCast<NiPSysCylinderEmitter>;
%include "obj/NiPSysData.h"
%template(NiPSysDataRef) Ref<NiPSysData>;
%template(DynamicCastToNiPSysData) DynamicCast<NiPSysData>;
%template(StaticCastToNiPSysData) StaticCast<NiPSysData>;
%include "obj/NiPSysDragModifier.h"
%template(NiPSysDragModifierRef) Ref<NiPSysDragModifier>;
%template(DynamicCastToNiPSysDragModifier) DynamicCast<NiPSysDragModifier>;
%template(StaticCastToNiPSysDragModifier) StaticCast<NiPSysDragModifier>;
%include "obj/NiPSysEmitterCtlr.h"
%template(NiPSysEmitterCtlrRef) Ref<NiPSysEmitterCtlr>;
%template(DynamicCastToNiPSysEmitterCtlr) DynamicCast<NiPSysEmitterCtlr>;
%template(StaticCastToNiPSysEmitterCtlr) StaticCast<NiPSysEmitterCtlr>;
%include "obj/NiPSysEmitterCtlrData.h"
%template(NiPSysEmitterCtlrDataRef) Ref<NiPSysEmitterCtlrData>;
%template(DynamicCastToNiPSysEmitterCtlrData) DynamicCast<NiPSysEmitterCtlrData>;
%template(StaticCastToNiPSysEmitterCtlrData) StaticCast<NiPSysEmitterCtlrData>;
%include "obj/NiPSysEmitterDeclinationCtlr.h"
%template(NiPSysEmitterDeclinationCtlrRef) Ref<NiPSysEmitterDeclinationCtlr>;
%template(DynamicCastToNiPSysEmitterDeclinationCtlr) DynamicCast<NiPSysEmitterDeclinationCtlr>;
%template(StaticCastToNiPSysEmitterDeclinationCtlr) StaticCast<NiPSysEmitterDeclinationCtlr>;
%include "obj/NiPSysEmitterDeclinationVarCtlr.h"
%template(NiPSysEmitterDeclinationVarCtlrRef) Ref<NiPSysEmitterDeclinationVarCtlr>;
%template(DynamicCastToNiPSysEmitterDeclinationVarCtlr) DynamicCast<NiPSysEmitterDeclinationVarCtlr>;
%template(StaticCastToNiPSysEmitterDeclinationVarCtlr) StaticCast<NiPSysEmitterDeclinationVarCtlr>;
%include "obj/NiPSysEmitterInitialRadiusCtlr.h"
%template(NiPSysEmitterInitialRadiusCtlrRef) Ref<NiPSysEmitterInitialRadiusCtlr>;
%template(DynamicCastToNiPSysEmitterInitialRadiusCtlr) DynamicCast<NiPSysEmitterInitialRadiusCtlr>;
%template(StaticCastToNiPSysEmitterInitialRadiusCtlr) StaticCast<NiPSysEmitterInitialRadiusCtlr>;
%include "obj/NiPSysEmitterLifeSpanCtlr.h"
%template(NiPSysEmitterLifeSpanCtlrRef) Ref<NiPSysEmitterLifeSpanCtlr>;
%template(DynamicCastToNiPSysEmitterLifeSpanCtlr) DynamicCast<NiPSysEmitterLifeSpanCtlr>;
%template(StaticCastToNiPSysEmitterLifeSpanCtlr) StaticCast<NiPSysEmitterLifeSpanCtlr>;
%include "obj/NiPSysEmitterSpeedCtlr.h"
%template(NiPSysEmitterSpeedCtlrRef) Ref<NiPSysEmitterSpeedCtlr>;
%template(DynamicCastToNiPSysEmitterSpeedCtlr) DynamicCast<NiPSysEmitterSpeedCtlr>;
%template(StaticCastToNiPSysEmitterSpeedCtlr) StaticCast<NiPSysEmitterSpeedCtlr>;
%include "obj/NiPSysGravityModifier.h"
%template(NiPSysGravityModifierRef) Ref<NiPSysGravityModifier>;
%template(DynamicCastToNiPSysGravityModifier) DynamicCast<NiPSysGravityModifier>;
%template(StaticCastToNiPSysGravityModifier) StaticCast<NiPSysGravityModifier>;
%include "obj/NiPSysGravityStrengthCtlr.h"
%template(NiPSysGravityStrengthCtlrRef) Ref<NiPSysGravityStrengthCtlr>;
%template(DynamicCastToNiPSysGravityStrengthCtlr) DynamicCast<NiPSysGravityStrengthCtlr>;
%template(StaticCastToNiPSysGravityStrengthCtlr) StaticCast<NiPSysGravityStrengthCtlr>;
%include "obj/NiPSysGrowFadeModifier.h"
%template(NiPSysGrowFadeModifierRef) Ref<NiPSysGrowFadeModifier>;
%template(DynamicCastToNiPSysGrowFadeModifier) DynamicCast<NiPSysGrowFadeModifier>;
%template(StaticCastToNiPSysGrowFadeModifier) StaticCast<NiPSysGrowFadeModifier>;
%include "obj/NiPSysMeshEmitter.h"
%template(NiPSysMeshEmitterRef) Ref<NiPSysMeshEmitter>;
%template(DynamicCastToNiPSysMeshEmitter) DynamicCast<NiPSysMeshEmitter>;
%template(StaticCastToNiPSysMeshEmitter) StaticCast<NiPSysMeshEmitter>;
%include "obj/NiPSysMeshUpdateModifier.h"
%template(NiPSysMeshUpdateModifierRef) Ref<NiPSysMeshUpdateModifier>;
%template(DynamicCastToNiPSysMeshUpdateModifier) DynamicCast<NiPSysMeshUpdateModifier>;
%template(StaticCastToNiPSysMeshUpdateModifier) StaticCast<NiPSysMeshUpdateModifier>;
%include "obj/NiPSysModifierActiveCtlr.h"
%template(NiPSysModifierActiveCtlrRef) Ref<NiPSysModifierActiveCtlr>;
%template(DynamicCastToNiPSysModifierActiveCtlr) DynamicCast<NiPSysModifierActiveCtlr>;
%template(StaticCastToNiPSysModifierActiveCtlr) StaticCast<NiPSysModifierActiveCtlr>;
%include "obj/NiPSysPlanarCollider.h"
%template(NiPSysPlanarColliderRef) Ref<NiPSysPlanarCollider>;
%template(DynamicCastToNiPSysPlanarCollider) DynamicCast<NiPSysPlanarCollider>;
%template(StaticCastToNiPSysPlanarCollider) StaticCast<NiPSysPlanarCollider>;
%include "obj/NiPSysPositionModifier.h"
%template(NiPSysPositionModifierRef) Ref<NiPSysPositionModifier>;
%template(DynamicCastToNiPSysPositionModifier) DynamicCast<NiPSysPositionModifier>;
%template(StaticCastToNiPSysPositionModifier) StaticCast<NiPSysPositionModifier>;
%include "obj/NiPSysResetOnLoopCtlr.h"
%template(NiPSysResetOnLoopCtlrRef) Ref<NiPSysResetOnLoopCtlr>;
%template(DynamicCastToNiPSysResetOnLoopCtlr) DynamicCast<NiPSysResetOnLoopCtlr>;
%template(StaticCastToNiPSysResetOnLoopCtlr) StaticCast<NiPSysResetOnLoopCtlr>;
%include "obj/NiPSysRotationModifier.h"
%template(NiPSysRotationModifierRef) Ref<NiPSysRotationModifier>;
%template(DynamicCastToNiPSysRotationModifier) DynamicCast<NiPSysRotationModifier>;
%template(StaticCastToNiPSysRotationModifier) StaticCast<NiPSysRotationModifier>;
%include "obj/NiPSysSpawnModifier.h"
%template(NiPSysSpawnModifierRef) Ref<NiPSysSpawnModifier>;
%template(DynamicCastToNiPSysSpawnModifier) DynamicCast<NiPSysSpawnModifier>;
%template(StaticCastToNiPSysSpawnModifier) StaticCast<NiPSysSpawnModifier>;
%include "obj/NiPSysSphereEmitter.h"
%template(NiPSysSphereEmitterRef) Ref<NiPSysSphereEmitter>;
%template(DynamicCastToNiPSysSphereEmitter) DynamicCast<NiPSysSphereEmitter>;
%template(StaticCastToNiPSysSphereEmitter) StaticCast<NiPSysSphereEmitter>;
%include "obj/NiPSysUpdateCtlr.h"
%template(NiPSysUpdateCtlrRef) Ref<NiPSysUpdateCtlr>;
%template(DynamicCastToNiPSysUpdateCtlr) DynamicCast<NiPSysUpdateCtlr>;
%template(StaticCastToNiPSysUpdateCtlr) StaticCast<NiPSysUpdateCtlr>;
%include "obj/NiRangeLODData.h"
%template(NiRangeLODDataRef) Ref<NiRangeLODData>;
%template(DynamicCastToNiRangeLODData) DynamicCast<NiRangeLODData>;
%template(StaticCastToNiRangeLODData) StaticCast<NiRangeLODData>;
%include "obj/NiRotatingParticles.h"
%template(NiRotatingParticlesRef) Ref<NiRotatingParticles>;
%template(DynamicCastToNiRotatingParticles) DynamicCast<NiRotatingParticles>;
%template(StaticCastToNiRotatingParticles) StaticCast<NiRotatingParticles>;
%include "obj/NiRotatingParticlesData.h"
%template(NiRotatingParticlesDataRef) Ref<NiRotatingParticlesData>;
%template(DynamicCastToNiRotatingParticlesData) DynamicCast<NiRotatingParticlesData>;
%template(StaticCastToNiRotatingParticlesData) StaticCast<NiRotatingParticlesData>;
%include "obj/NiScreenLODData.h"
%template(NiScreenLODDataRef) Ref<NiScreenLODData>;
%template(DynamicCastToNiScreenLODData) DynamicCast<NiScreenLODData>;
%template(StaticCastToNiScreenLODData) StaticCast<NiScreenLODData>;
%include "obj/NiSequenceStreamHelper.h"
%template(NiSequenceStreamHelperRef) Ref<NiSequenceStreamHelper>;
%template(DynamicCastToNiSequenceStreamHelper) DynamicCast<NiSequenceStreamHelper>;
%template(StaticCastToNiSequenceStreamHelper) StaticCast<NiSequenceStreamHelper>;
%include "obj/NiShadeProperty.h"
%template(NiShadePropertyRef) Ref<NiShadeProperty>;
%template(DynamicCastToNiShadeProperty) DynamicCast<NiShadeProperty>;
%template(StaticCastToNiShadeProperty) StaticCast<NiShadeProperty>;
%include "obj/NiSkinData.h"
%template(NiSkinDataRef) Ref<NiSkinData>;
%template(DynamicCastToNiSkinData) DynamicCast<NiSkinData>;
%template(StaticCastToNiSkinData) StaticCast<NiSkinData>;
%include "obj/NiSkinInstance.h"
%template(NiSkinInstanceRef) Ref<NiSkinInstance>;
%template(DynamicCastToNiSkinInstance) DynamicCast<NiSkinInstance>;
%template(StaticCastToNiSkinInstance) StaticCast<NiSkinInstance>;
%include "obj/NiSkinPartition.h"
%template(NiSkinPartitionRef) Ref<NiSkinPartition>;
%template(DynamicCastToNiSkinPartition) DynamicCast<NiSkinPartition>;
%template(StaticCastToNiSkinPartition) StaticCast<NiSkinPartition>;
%include "obj/NiSourceTexture.h"
%template(NiSourceTextureRef) Ref<NiSourceTexture>;
%template(DynamicCastToNiSourceTexture) DynamicCast<NiSourceTexture>;
%template(StaticCastToNiSourceTexture) StaticCast<NiSourceTexture>;
%include "obj/NiSpecularProperty.h"
%template(NiSpecularPropertyRef) Ref<NiSpecularProperty>;
%template(DynamicCastToNiSpecularProperty) DynamicCast<NiSpecularProperty>;
%template(StaticCastToNiSpecularProperty) StaticCast<NiSpecularProperty>;
%include "obj/NiSphericalCollider.h"
%template(NiSphericalColliderRef) Ref<NiSphericalCollider>;
%template(DynamicCastToNiSphericalCollider) DynamicCast<NiSphericalCollider>;
%template(StaticCastToNiSphericalCollider) StaticCast<NiSphericalCollider>;
%include "obj/NiSpotLight.h"
%template(NiSpotLightRef) Ref<NiSpotLight>;
%template(DynamicCastToNiSpotLight) DynamicCast<NiSpotLight>;
%template(StaticCastToNiSpotLight) StaticCast<NiSpotLight>;
%include "obj/NiStencilProperty.h"
%template(NiStencilPropertyRef) Ref<NiStencilProperty>;
%template(DynamicCastToNiStencilProperty) DynamicCast<NiStencilProperty>;
%template(StaticCastToNiStencilProperty) StaticCast<NiStencilProperty>;
%include "obj/NiStringExtraData.h"
%template(NiStringExtraDataRef) Ref<NiStringExtraData>;
%template(DynamicCastToNiStringExtraData) DynamicCast<NiStringExtraData>;
%template(StaticCastToNiStringExtraData) StaticCast<NiStringExtraData>;
%include "obj/NiStringPalette.h"
%template(NiStringPaletteRef) Ref<NiStringPalette>;
%template(DynamicCastToNiStringPalette) DynamicCast<NiStringPalette>;
%template(StaticCastToNiStringPalette) StaticCast<NiStringPalette>;
%include "obj/NiStringsExtraData.h"
%template(NiStringsExtraDataRef) Ref<NiStringsExtraData>;
%template(DynamicCastToNiStringsExtraData) DynamicCast<NiStringsExtraData>;
%template(StaticCastToNiStringsExtraData) StaticCast<NiStringsExtraData>;
%include "obj/NiTextKeyExtraData.h"
%template(NiTextKeyExtraDataRef) Ref<NiTextKeyExtraData>;
%template(DynamicCastToNiTextKeyExtraData) DynamicCast<NiTextKeyExtraData>;
%template(StaticCastToNiTextKeyExtraData) StaticCast<NiTextKeyExtraData>;
%include "obj/NiTextureEffect.h"
%template(NiTextureEffectRef) Ref<NiTextureEffect>;
%template(DynamicCastToNiTextureEffect) DynamicCast<NiTextureEffect>;
%template(StaticCastToNiTextureEffect) StaticCast<NiTextureEffect>;
%include "obj/NiTextureTransformController.h"
%template(NiTextureTransformControllerRef) Ref<NiTextureTransformController>;
%template(DynamicCastToNiTextureTransformController) DynamicCast<NiTextureTransformController>;
%template(StaticCastToNiTextureTransformController) StaticCast<NiTextureTransformController>;
%include "obj/NiTexturingProperty.h"
%template(NiTexturingPropertyRef) Ref<NiTexturingProperty>;
%template(DynamicCastToNiTexturingProperty) DynamicCast<NiTexturingProperty>;
%template(StaticCastToNiTexturingProperty) StaticCast<NiTexturingProperty>;
%include "obj/NiTransformController.h"
%template(NiTransformControllerRef) Ref<NiTransformController>;
%template(DynamicCastToNiTransformController) DynamicCast<NiTransformController>;
%template(StaticCastToNiTransformController) StaticCast<NiTransformController>;
%include "obj/NiTransformData.h"
%template(NiTransformDataRef) Ref<NiTransformData>;
%template(DynamicCastToNiTransformData) DynamicCast<NiTransformData>;
%template(StaticCastToNiTransformData) StaticCast<NiTransformData>;
%include "obj/NiTransformInterpolator.h"
%template(NiTransformInterpolatorRef) Ref<NiTransformInterpolator>;
%template(DynamicCastToNiTransformInterpolator) DynamicCast<NiTransformInterpolator>;
%template(StaticCastToNiTransformInterpolator) StaticCast<NiTransformInterpolator>;
%include "obj/NiTriShape.h"
%template(NiTriShapeRef) Ref<NiTriShape>;
%template(DynamicCastToNiTriShape) DynamicCast<NiTriShape>;
%template(StaticCastToNiTriShape) StaticCast<NiTriShape>;
%include "obj/NiTriShapeData.h"
%template(NiTriShapeDataRef) Ref<NiTriShapeData>;
%template(DynamicCastToNiTriShapeData) DynamicCast<NiTriShapeData>;
%template(StaticCastToNiTriShapeData) StaticCast<NiTriShapeData>;
%include "obj/NiTriStrips.h"
%template(NiTriStripsRef) Ref<NiTriStrips>;
%template(DynamicCastToNiTriStrips) DynamicCast<NiTriStrips>;
%template(StaticCastToNiTriStrips) StaticCast<NiTriStrips>;
%include "obj/NiTriStripsData.h"
%template(NiTriStripsDataRef) Ref<NiTriStripsData>;
%template(DynamicCastToNiTriStripsData) DynamicCast<NiTriStripsData>;
%template(StaticCastToNiTriStripsData) StaticCast<NiTriStripsData>;
%include "obj/NiUVController.h"
%template(NiUVControllerRef) Ref<NiUVController>;
%template(DynamicCastToNiUVController) DynamicCast<NiUVController>;
%template(StaticCastToNiUVController) StaticCast<NiUVController>;
%include "obj/NiUVData.h"
%template(NiUVDataRef) Ref<NiUVData>;
%template(DynamicCastToNiUVData) DynamicCast<NiUVData>;
%template(StaticCastToNiUVData) StaticCast<NiUVData>;
%include "obj/NiVectorExtraData.h"
%template(NiVectorExtraDataRef) Ref<NiVectorExtraData>;
%template(DynamicCastToNiVectorExtraData) DynamicCast<NiVectorExtraData>;
%template(StaticCastToNiVectorExtraData) StaticCast<NiVectorExtraData>;
%include "obj/NiVertexColorProperty.h"
%template(NiVertexColorPropertyRef) Ref<NiVertexColorProperty>;
%template(DynamicCastToNiVertexColorProperty) DynamicCast<NiVertexColorProperty>;
%template(StaticCastToNiVertexColorProperty) StaticCast<NiVertexColorProperty>;
%include "obj/NiVertWeightsExtraData.h"
%template(NiVertWeightsExtraDataRef) Ref<NiVertWeightsExtraData>;
%template(DynamicCastToNiVertWeightsExtraData) DynamicCast<NiVertWeightsExtraData>;
%template(StaticCastToNiVertWeightsExtraData) StaticCast<NiVertWeightsExtraData>;
%include "obj/NiVisController.h"
%template(NiVisControllerRef) Ref<NiVisController>;
%template(DynamicCastToNiVisController) DynamicCast<NiVisController>;
%template(StaticCastToNiVisController) StaticCast<NiVisController>;
%include "obj/NiVisData.h"
%template(NiVisDataRef) Ref<NiVisData>;
%template(DynamicCastToNiVisData) DynamicCast<NiVisData>;
%template(StaticCastToNiVisData) StaticCast<NiVisData>;
%include "obj/NiWireframeProperty.h"
%template(NiWireframePropertyRef) Ref<NiWireframeProperty>;
%template(DynamicCastToNiWireframeProperty) DynamicCast<NiWireframeProperty>;
%template(StaticCastToNiWireframeProperty) StaticCast<NiWireframeProperty>;
%include "obj/NiZBufferProperty.h"
%template(NiZBufferPropertyRef) Ref<NiZBufferProperty>;
%template(DynamicCastToNiZBufferProperty) DynamicCast<NiZBufferProperty>;
%template(StaticCastToNiZBufferProperty) StaticCast<NiZBufferProperty>;
%include "obj/RootCollisionNode.h"
%template(RootCollisionNodeRef) Ref<RootCollisionNode>;
%template(DynamicCastToRootCollisionNode) DynamicCast<RootCollisionNode>;
%template(StaticCastToRootCollisionNode) StaticCast<RootCollisionNode>;
%include "gen/ByteArray.h"
%include "gen/Footer.h"
%include "gen/LODRange.h"
%include "gen/MatchGroup.h"
%include "gen/MipMap.h"
%include "gen/NodeGroup.h"
%include "gen/QuaternionXYZW.h"
%include "gen/ShortString.h"
%include "gen/SkinShape.h"
%include "gen/SkinShapeGroup.h"
%include "gen/SkinWeight.h"
%include "gen/AVObject.h"
%include "gen/ControllerLink.h"
%include "gen/Header.h"
%include "gen/StringPalette.h"
%include "gen/TBC.h"
%include "gen/KeyGroup.h"
%include "gen/RotationKeyArray.h"
%include "gen/TexDesc.h"
%include "gen/ShaderTexDesc.h"
%include "gen/TexSource.h"
%include "gen/SkinPartition.h"
%include "gen/BoundingBox.h"
%include "gen/FurniturePosition.h"
%include "gen/hkTriangle.h"
%include "gen/Morph.h"
%include "gen/Particle.h"
%include "gen/SkinData.h"
%include "gen/RagDollDescriptor.h"
%include "gen/LimitedHingeDescriptor.h"

%template(vector_NiAVObjectRef) std::vector<NiAVObjectRef>;
